@@ -39,13 +39,13 @@ public:
     /**
      * Destructor
      */
-    virtual ~WindowDefinitionWidget();
+    ~WindowDefinitionWidget() override;
 
-    bool isChanged() const Q_DECL_OVERRIDE;
+    bool isChanged() const override;
 
 protected:
-    void doCopyFromObject() Q_DECL_OVERRIDE;
-    void doCopyToObject() Q_DECL_OVERRIDE;
+    void doCopyFromObject() override;
+    void doCopyToObject() override;
 
 private Q_SLOTS:
 
@@ -86,12 +86,12 @@ public:
         connect(buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
     }
 
-    ~WindowDefinitionDialog()
+    ~WindowDefinitionDialog() override
     {
         def = nullptr;
     }
 
-    void accept() Q_DECL_OVERRIDE
+    void accept() override
     {
         def->copyToObject();
         QDialog::accept();
